@@ -46,9 +46,12 @@ struct _GailEntry
   /*
    * These fields store information about text changed
    */
-  gchar          *signal_name;
-  gint           position;
-  gint           length;
+  gchar          *signal_name_insert;
+  gchar          *signal_name_delete;
+  gint           position_insert;
+  gint           position_delete;
+  gint           length_insert;
+  gint           length_delete;
   gint           cursor_position;
   gint           selection_bound;
 
@@ -56,6 +59,7 @@ struct _GailEntry
   gchar          *activate_keybinding;
   guint          action_idle_handler;
   guint          insert_idle_handler;
+  guint          delete_idle_handler;
 };
 
 GType gail_entry_get_type (void);
