@@ -56,6 +56,9 @@ static void                  menu_item_selection           (GtkItem        *item
 static gboolean              find_accel                    (GtkAccelKey    *key,
                                                             GClosure       *closure,
                                                             gpointer       data);
+static gboolean              find_accel_new                (GtkAccelKey    *key,
+                                                            GClosure       *closure,
+                                                            gpointer       data);
 
 static gpointer parent_class = NULL;
 
@@ -516,16 +519,39 @@ gail_menu_item_get_keybinding (AtkAction *action,
           GtkAccelKey *key;
 
           group = gtk_menu_get_accel_group (GTK_MENU (parent));
+
           if (group)
             {
               key = gtk_accel_group_find (group, find_accel, item);
+            }
+          else
+            {
+              /*
+               * If the menu item is created using GtkAction and GtkUIManager
+               * we get here.
+               */
+              key = NULL;
+              child = GTK_BIN (item)->child;
+              if (GTK_IS_ACCEL_LABEL (child))
+                {
+                  GtkAccelLabel *accel_label;
 
-              if (key)
-                {           
-                  accelerator = gtk_accelerator_name (key->accel_key,
-                                                      key->accel_mods);
+                  accel_label = GTK_ACCEL_LABEL (child);
+                  if (accel_label->accel_closure)
+                    {
+                      key = gtk_accel_group_find (accel_label->accel_group,
+                                                  find_accel_new,
+                                                  accel_label->accel_closure);
+                    }
+               
                 }
             }
+
+          if (key)
+            {           
+              accelerator = gtk_accelerator_name (key->accel_key,
+                                                  key->accel_mods);
+            }
         }
     }
   /*
@@ -636,3 +662,11 @@ find_accel (GtkAccelKey *key,
    */
   return data == (gpointer) closure->data;
 }
+
+static gboolean
+find_accel_new (GtkAccelKey *key,
+                GClosure    *closure,
+                gpointer     data)
+{
+  return data == (gpointer) closure;
+}
